#include "ctetris.h"
#include "screen.h"
#include "game.h"

char quit = 0, old_style_keys = 0;

void handle_quit_signal(const int code)
{
	if(quit > 1)
	{
		restore_screen();
		exit(0);
	}
	quit = 3;
}

unsigned char get_rand(const unsigned char i)
{
	return (unsigned char)rand() % i;
}

int main(int argc, char *argv[])
{
	int optchr;
	umask(S_IXUSR | S_IXGRP | S_IXOTH);
	signal(SIGKILL, handle_quit_signal);
	signal(SIGWINCH, handle_quit_signal);
	signal(SIGTERM, handle_quit_signal);
	signal(SIGINT, handle_quit_signal);
	signal(SIGQUIT, handle_quit_signal);
	while((optchr = getopt(argc, argv, "hvros")) != EOF)
	{
		switch(optchr)
		{
			case 'h':
				printf("Help:\n\
-h             parameter list\n\
-o             use old style keys\n\
-v             version info\n\
-r             remove highscore-file\n");
				quit = 1;
				break;
			case 'v':
				printf("\
ctetris %s, built on %s.\n\
(c) Dominik Hackl [dominik@hackl.dhs.org]\n\
Homepage: http://www.sourceforge.com/projects/ctetris\n\
ALL PARTS OF CTETRIS ARE UNDER THE TERMS OF GPL. SEE DOCUMENTATION FOR MORE INFO\n\
", VERSION, __DATE__);
				quit = 1;
				break;
			case 'r':
				printf("removing highscore-file (\"%s\")...", HIGHSCORE_FILE_PATH);
				if(remove(HIGHSCORE_FILE_PATH) == 0)
				{
					printf("done\n");
				}
				else
				{
					printf("failed\n");
				}
				quit = 1;
				break;
			case 'o':
				old_style_keys = 1;
				break;
			default:
				break;
		}
	}
	if(quit != 0)
	{
		return 0;
	}
	if(init_screen() != 0)
	{
		return 1;
	}
	do
	{
		start_game();
	} while(quit == 1 && play_again() ==  0);
	restore_screen();
	return 0;
}


